v%%\ This is a collection of Matlab-code used to describe the horizontal structure 
%%\ of the model ocean in my thesis. Use inset.m by calling inset(main_handle, 
%%\ inset_handle, inset_size, title) where title == 1 refers to depth as label 
%%\ in colorbar, title == 2 is temperature, title == 3 is meridional velocity 
%%\ and title == 4 is zonal velocity.


%% Load the model output

clear;
close all;

addpath /mn/vann/metos-d5/adagj/MatlabTools/m_map/
addpath /mn/vann/metos-d5/adagj/MatlabTools/coastline/
load globalcoastLR.dat

lon_c = rdmds('../Grid/XC');
lat_c = rdmds('../Grid/YC');
height_c = rdmds('../Grid/RC');
height_f = rdmds('../Grid/RF');
h=rdmds('../Depth_wall_block/Depth');

n_time = 876000*(15:20);
u_ave = rdmds('uVeltave',n_time);
v_ave = rdmds('vVeltave',n_time);
T_ave = rdmds('Ttave',n_time);
w_ave = rdmds('wVeltave',n_time);
T_ave = mean(T_ave,4);
u_ave = mean(u_ave,4);
v_ave = mean(v_ave,4);
w_ave = mean(w_ave,4);

%\ Make horizontal velocities centered in gridbox

u_c = zeros(size(u_ave));
v_c = zeros(size(v_ave));
for i = 1:length(lon_c(:,1))-1
    u_c(i,:,:) = (1./2)*(u_ave(i,:,:)+u_ave(i+1,:,:));
end
for k = 1:length(lat_c(1,:))-1
    v_c(:,k,:) = (1./2)*(v_ave(:,k,:)+v_ave(:,k+1,:));
end

u_c(end,:,:) = (1./2)*(u_ave(end,:,:)+u_ave(1,:,:));
v_c(:,end,:) = v_ave(:,end,:);

%%\ Vertical sections of: temperature, zonal and meridional velocity


close all
level_n = 1;
basin = 1;
if basin == 1                             % Global
    x_min = 1;
    x_max = 359;
    y_min = -79;
    y_max = 85;

    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);
    x_lat = 0;
    x_lat2 = 0;
    
    % Plot surface temperature 
    
    n = 1;
    T_surf = squeeze(T_ave(:,:,n));
    m_contourf(lon_c,lat_c,T_surf,75)
    colorbar
    m_coast('patch',[0.7 0.7 0.7],'edgecolor','black');
    m_grid('linestyle','non')
    title(['\bf T[\circC] at' num2str(height_c(1,1,n)) 'm depth'])
    xlabel('\bf Longitude')
    ylabel('\bf Latitude')
elseif basin == 2                         % Atlantic
  
    x_min = 283;
    x_max = 359;
    y_min = -21;
    y_max = 71;
       
elseif basin == 3                         % Pacific
    x_min = 101;
    x_max = 295;
    y_min = -33;
    y_max = 69;
    
    %%\ Indonesian Passage line
 
    longitude_line = 129:-2:115;
    lon_ind = zeros(1,length(longitude_line));
    for ii = 1:length(longitude_line)
        lon_ind(ii) = find(lon_c(:,1) == longitude_line(ii));
    end
    latitude_line = -15:2:-1;
    lat_ind = zeros(1,length(latitude_line));
    for i = 1:length(latitude_line)
        lat_ind(i) = find(lat_c(1,:) == latitude_line(i));
    end
   
elseif basin == 4                         % Agulhas
    x_min = 11;
    x_max = 63;
    y_min = -55;
    y_max = -9;
    
elseif basin == 5                         % South America
    x_min = 277;
    x_max = 345;
    y_min = -73;
    y_max = -19;

    %%\ Drake Passage line
    
    longitude = 291;
    lon_ind = find(lon_c(:,1) == longitude);

    latitude_line = -69:2:-53;
    lat_ind = zeros(1,length(latitude_line));
    for i = 1:length(latitude_line)
        lat_ind(i) = find(lat_c(1,:) == latitude_line(i));
    end
    longitude_line = longitude*ones(1,length(latitude_line));   
    
    %%\ Calculate transport through Drake Passage
    [m,n] = size(lon_c);
    dy = 6371000*pi/n;
    
    U_drake = squeeze(u_c(lon_ind,lat_ind,:));
    U_drake = sum(U_drake,1)*dy;

    Vol_drake = 0;
    for j = 1 : length(height_c)
        Vol_drake = Vol_drake+U_drake(j)*abs(height_f(1,1,j+1)-height_f(j));
    end

    Vol_drake_Sv = 10^(-6)*Vol_drake; % in Sverdrup [10^6m^3/s]
end

u = squeeze(u_c(:,:,level_n));
v = squeeze(v_c(:,:,level_n));

% Dont plot velocities over land

[r,c]= find(-h>=0);
for k = 1:length(r)
    u(r(k),c(k)) = NaN;
    v(r(k),c(k)) = NaN;
end

% Dont plot velocities at height level n

[r2,c2]= find(-h>height_c(1,1,level_n));
for j = 1:length(r2)
    u(r2(j),c2(j)) = NaN;
    v(r2(j),c2(j)) = NaN;
end

nanre_surf = ~isnan(u) & ~isnan(v); 

% To plot fewer arrows

new_lon=lon_c(1:2:end, 1:2:end);
new_lat=lat_c(1:2:end, 1:2:end);
n_surf_u = u(1:2:end,1:2:end);
n_surf_v = v(1:2:end,1:2:end);
nanre_surf_less_arr = ~isnan(n_surf_u) & ~isnan(n_surf_v);
      
% Plot figure

if level_n == 1
    V2 = [0 0];
    colormap([0.7 0.7 0.7])
else V2 = [0, height_c(1,1,level_n)];  
    colormap([0.3 0.3 0.3; 0.7 0.7 0.7])
end

s = height_c(1,1,level_n);
fig1=figure(1);
contourf(lon_c,lat_c,-h,V2)
hold on

%%\ Add Indonesian or Drake Passage line
if basin == 3 || basin == 5
    plot(longitude_line, latitude_line, '--k', 'linewidth', 2)
end

%%\ Make a quiver plot and a reference vector

if level_n<10
    scale_factor = 100;
    u_reference = 0.10;
else 
    scale_factor = 500;
    u_reference = 0.01;
end

scale_factor_arrowhead = 2.;
v_reference = 0;
if basin == 1
    % Less arrows when looking at global ocean
    av =quiver(new_lon(nanre_surf_less_arr),new_lat(nanre_surf_less_arr),n_surf_u(nanre_surf_less_arr)*scale_factor,...
    n_surf_v(nanre_surf_less_arr)*scale_factor,'Color',[0 0 1], 'AutoScale','off');
    x_ref =  85;
    y_ref = 55;
    adjust_quiver_arrowhead_size(av, scale_factor_arrowhead);
    av2 = quiver(x_ref,y_ref,u_reference*scale_factor,v_reference*scale_factor,'AutoScale','off', 'Color',[0 0 1]);
    adjust_quiver_arrowhead_size(av2, scale_factor_arrowhead*3);
elseif basin == 2
    av =quiver(lon_c(nanre_surf),lat_c(nanre_surf),u(nanre_surf)*scale_factor,v(nanre_surf)*scale_factor,'Color',[0 0 1], 'AutoScale','off');
    x_ref = 319;
    y_ref = 73;
    adjust_quiver_arrowhead_size(av, scale_factor_arrowhead);
    av2 = quiver(x_ref,y_ref,u_reference*scale_factor,v_reference*scale_factor,'AutoScale','off', 'Color',[0 0 1]);
    adjust_quiver_arrowhead_size(av2, scale_factor_arrowhead*3);
elseif basin == 3 
    av =quiver(lon_c(nanre_surf),lat_c(nanre_surf),u(nanre_surf)*scale_factor,v(nanre_surf)*scale_factor,'Color',[0 0 1], 'AutoScale','off');
    x_ref = 118;
    y_ref = 50;
    adjust_quiver_arrowhead_size(av, scale_factor_arrowhead);
    av2 = quiver(x_ref,y_ref,u_reference*scale_factor,v_reference*scale_factor,'AutoScale','off', 'Color',[0 0 1]);
    adjust_quiver_arrowhead_size(av2, scale_factor_arrowhead*3);
else 
    av =quiver(lon_c(nanre_surf),lat_c(nanre_surf),u(nanre_surf)*scale_factor,v(nanre_surf)*scale_factor,'Color',[0 0 1], 'AutoScale','off');
    adjust_quiver_arrowhead_size(av, scale_factor_arrowhead);
end


xlim([x_min x_max])
ylim([y_min y_max])
if basin == 1
    title(['\bf Horizontal velocities at' num2str(s) ' m depth'])
elseif basin == 2
    title(['\bf Atlantic Ocean: Horizontal velocities at' num2str(s) ' m depth'])
    axis square
elseif basin == 3
    title(['\bf Pacific Ocean: Horizontal velocities at' num2str(s) ' m depth'])
elseif basin == 4 
    title(['\bf South Africa: Horizontal velocities at' num2str(s) ' m depth'])
elseif basin == 4 
    title(['\bf South America: Horizontal velocities at' num2str(s) ' m depth'])
end

set(gca,'fontsize',10)
xlabel('\bf Longitude')
ylabel('\bf Latitude')

if basin == 4 || basin == 5

    fig2=figure(2);
    contourf(lon_c,lat_c, -h,[0 0], 'Color', 'k', 'linewidth',1)
    rectangle('Position',[x_min, y_min, x_max-x_min, y_max-y_min], 'linewidth',3)
    set(gca,'XTickLabel',[])
    set(gca,'YTickLabel',[])
    ylim([-88 88])

    [h_m h_i]=inset_low(fig1,fig2,0.35);

    colormap([0.7 0.7 0.7])

    close(figure(1))
    close(figure(2))
end

%%\ Plot vertical velocity at a depth level on global map

vert_level = 6;

m_proj('miller','lat',[-61 67], 'lon', [1 359])

if basin == 1
    for i = 1:length(vert_level)
        w_depth_level = squeeze(w_ave(:,:,vert_level(i)));
        figure(199);
        m_pcolor(lon_c,lat_c,w_depth_level)
        hold on
        caxis([-10^(-6) 10^(-6)])
        shading('interp')
        colorbar
        %colormap(gray)
        %freezeColors;

        % Superimpose horizontal velocities
        m_quiver(new_lon(nanre_surf_less_arr),new_lat(nanre_surf_less_arr),n_surf_u(nanre_surf_less_arr)*scale_factor,...
        n_surf_v(nanre_surf_less_arr)*scale_factor,'Color',[0 0 1], 'AutoScale','off');
        %m_quiver(lon_c(nanre_surf),lat_c(nanre_surf),u(nanre_surf)*scale_factor,...
        %    v(nanre_surf)*scale_factor,'Color',[1 0 0],'AutoScale','off');
        hold off
   
        m_coast('patch',[0.7 0.7 0.7],'edgecolor','black');
        m_grid('linestyle','non')
        title(['\bf Vertical velocity (m/s) at' num2str(height_f(vert_level(i)))...
            ' m depth. Superimposed are the surface velocities.'])
        xlabel('\bf Longitude')
        ylabel('\bf Latitude')
    
        hold off
    end    
end
    

%%\ Calculate maximum speed in domain

%speed_v = sqrt(u.^2+v.^2);
%max_speed = max(max(speed_v(x_index1:x_index2,y_index1:y_index2)))
%[max_lon,max_lat] = find(speed_v(x_index1:x_index2,y_index1:y_index2)>=max_speed);


% % Calculate transport through Indonesian Passage
% 
% 
% [m,n] = size(lon_c);
% dy = 6371000*pi/n;
% dx = zeros(1,length(longitude_line));
% dr = zeros(1,length(longitude_line));
% Hh = zeros(1,length(longitude_line));
% Tot_v = zeros(length(longitude_line), length(height_c));
% for ir = 1:length(longitude_line)
%     dx(ir) = (2*cosd(latitude_line(ir))*6371000*pi)/m;
%     dr(ir) = sqrt(dx(ir)^2+dy^2);
%     U_ind = squeeze(u_c(lon_ind(ir),lat_ind(ir),:));
%     V_ind = squeeze(v_c(lon_ind(ir),lat_ind(ir),:));
%     Tot_v(ir,:) =  sqrt(U_ind.^2 + V_ind.^2)*dr(ir);
%     
%     % depth in the different points
%     Hh(ir) = -h(lon_ind(ir),lat_ind(ir));
% end
% 
% Tot_v_tra = sum(Tot_v,1);
% H_max = min(Hh);
% 
% Vol_ind = 0;
% for j = 1 : length(height_c)
%     if height_f(1,1,j+1)<H_max
%         Vol_ind = Vol_ind+Tot_v_tra(j)*abs(H_max-height_f(j));
%     else
%         Vol_ind = Vol_ind+Tot_v_tra(j)*abs(height_f(1,1,j+1)-height_f(j));
%     end
% end
% 
% Vol_ind_Sv = 10^(-6)*Vol_ind; % in Sverdrup [10^6m^3/s]

% Calculate transport through Drake passage

% [m,n] = size(lon_c);
% dy = 6371000*pi/n;
% U_drake = squeeze(u_c(lon_ind,lat_ind(:),:));
% U_drake = sum(U_drake,1)*dy;
% 
% Vol_drake = 0;
% for j = 1 : length(height_c)
%     Vol_drake = Vol_drake+U_drake(j)*abs(height_f(1,1,j+1)-height_f(j));
% end
% 
% Vol_drake_Sv = 10^(-6)*Vol_drake % in Sverdrup [10^6m^3/s]