%%\ This is a collection of Matlab-code used to describe the vertical structure 
%%\ of the model ocean in my thesis. Use inset.m by calling inset(main_handle, 
%%\ inset_handle, inset_size, title) where title == 1 refers to depth as label 
%%\ in colorbar, title == 2 is temperature, title == 3 is meridional velocity 
%%\ and title == 4 is zonal velocity.


%% Load the model output

clear;
close all;

addpath /mn/vann/metos-d5/adagj/MatlabTools/m_map/
addpath /mn/vann/metos-d5/adagj/MatlabTools/coastline/
load globalcoastLR.dat

lon_c = rdmds('../Grid/XC');
lat_c = rdmds('../Grid/YC');
height_c = rdmds('../Grid/RC');
height_f = rdmds('../Grid/RF');
h=rdmds('../Depth_wall_block/Depth');

n_time = 876000*(15:20);
u_ave = rdmds('uVeltave',n_time);
v_ave = rdmds('vVeltave',n_time);
T_ave = rdmds('Ttave',n_time);
w_ave = rdmds('wVeltave',n_time);
T_ave = mean(T_ave,4);
u_ave = mean(u_ave,4);
v_ave = mean(v_ave,4);
w_ave = mean(w_ave,4);

%\ Make horizontal velocities centered in gridbox

u_c = zeros(size(u_ave));
v_c = zeros(size(v_ave));
for i = 1:length(lon_c(:,1))-1
    u_c(i,:,:) = (1./2)*(u_ave(i,:,:)+u_ave(i+1,:,:));
end
for k = 1:length(lat_c(1,:))-1
    v_c(:,k,:) = (1./2)*(v_ave(:,k,:)+v_ave(:,k+1,:));
end

u_c(end,:,:) = (1./2)*(u_ave(end,:,:)+u_ave(1,:,:));
v_c(:,end,:) = v_ave(:,end,:);

%\ Vertical sections of: temperature, zonal and meridional velocity

close all
basin = 2;
if basin == 1                             % Global
    x_min = 1;
    x_max = 359;
    y_min = -79;
    y_max = 81;

    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);
    x_lat = 0;
    x_lat2 = 0;
    T_grid = T_ave;
    h_grid = h;
    latitude = 41;
    longitude = 347;
elseif basin == 2                         % Atlantic
    delay_grid = 100;
    % Boundaries used when computing average temperature
    x_min = 63;
    x_max = 221;
    %y_min = -33;
    y_min = 25;
    y_max = 71;

    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);
    
    x_lat = 12;
    x_lat2 = 0;
    latitude = 41;
    longitude = 347;
    % Make Atlantic the center
    h_grid = [h(delay_grid:end,:)' h(1:delay_grid-1,:)'];
    h_grid = h_grid';

    T_grid = zeros(size(T_ave));
    for isum = 1:length(lat_c(1,:))
        T_news = squeeze(T_ave(:,isum,:));
        T_news= [T_news(delay_grid:end,:)' T_news(1:delay_grid-1,:)'];
        T_news = T_news';
        T_grid(:,isum,:) = T_news;
    end
    
    % Test that grid-values are displaced correctly

    figure(100);
    pcolor(lon_c,lat_c,T_ave(:,:,1))
    hold on
    contourf(lon_c,lat_c,-h, [0 0], 'Linewidth', 2)
    hold off 
    figure(101);
    pcolor(lon_c,lat_c,T_grid(:,:,1))
    hold on
    contourf(lon_c,lat_c,-h_grid, [0 0], 'Linewidth', 2)
    hold off
elseif basin == 3                         % Pacific
    x_min = 101;
    x_max = 295;
    y_min = -33;
    y_max = 69;
    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);
    
    x_lat = 12;
    x_lat2 = 26;
    latitude = 41;
    longitude = 195;
    T_grid = T_ave;
    h_grid = h;
elseif basin == 4                         % Indian Ocean
    x_min = 31;
    x_max = 131;
    y_min = -73;
    y_max = 31;

    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);

    x_lat = 5;
    x_lat2 = 10;   
    latitude = 1;
    longitude = 89;
    T_grid = T_ave;
    h_grid = h;
elseif basin == 5                        % Antarctica region
    x_min = 277;
    x_max = 345;
    y_min = -73;
    y_max = -1;
    longitude = 291;
    longitude_line = -69:2:-53;
    %longitude_line = -75:2:-45;
    x_index1 = find(lon_c(:,1)== x_min);
    x_index2 = find(lon_c(:,1)== x_max);
    y_index1 = find(lat_c(1,:)==longitude_line(1,1));
    y_index2 = find(lat_c(1,:)==longitude_line(1,end));
    x_lat = 0;
    x_lat2 = 0;
    latitude = -61;
end

%%\ Zonally averaged temperature 

if basin == 1 || basin == 2 || basin == 3 
    x_grid = lon_c(x_index1:x_index2,y_index1:y_index2);
    y_grid = lat_c(x_index1:x_index2,y_index1:y_index2);    
    T_grid = T_grid(x_index1:x_index2,y_index1:y_index2,:);
    h_grid_nonNaN = h_grid(x_index1:x_index2,y_index1:y_index2);

    [r, c] = find(-h_grid>=0);
    for j = 1:length(r)
        h_grid(r(j),c(j)) = NaN;
    end 
    h_grid_NaN = h_grid(x_index1:x_index2,y_index1:y_index2);

    % Find eastern and western points in basin

    figure(50);
    pcolor(x_grid,y_grid,-h_grid_NaN)
    xlabel('\bf Longitude')
    ylabel('\bf Latitude')
    hold on 
    caxis([-120 0])
    colorbar
 
    [lon_points,lat_points] = size(h_grid_NaN);
    L_w = zeros(1,lat_points);
    L_e = zeros(1,lat_points);
    for i = 1:lat_points
        if basin == 1                    % The global one
            L_w(1,i) = x_index1;
            L_e(1,i) = x_index2;
        elseif basin == 2                % The Atlantic
            L_w_first = find(isnan(h_grid_NaN(1:23,i)),1,'last');
            if isempty(L_w_first)
                L_w(1,i) = 1;
            else
                L_w(1,i) = L_w_first;
            end
            L_e_first = find(isnan(h_grid_NaN(41:end,i)),1);
            if isempty(L_e_first)
                L_e(1,i) = lon_points;
            else
                L_e(1,i) = 40+L_e_first;
            end
        elseif basin == 3                % The Pacific
            L_w_first = find(isnan(h_grid_NaN(:,i)),1);
            if isempty(L_w_first) 
                L_w(1,i) = 1;
            else
                L_w(1,i) = L_w_first;
            end
            if basin == 2
                L_e_first = find(isnan(h_grid_NaN(41:end,i)),1);
                if isempty(L_e_first)
                    L_e(1,i) = lon_points;
                else
                    L_e(1,i) = 40+L_e_first;
                end
            elseif basin == 3
                L_e_first = find(isnan(h_grid_NaN(56:end,i)),1);
                if isempty(L_e_first)
                    L_e(1,i) = lon_points;
                else
                    L_e(1,i) = 55+L_e_first;
                end
            end
        end
        plot(x_grid(L_w(1,i),i),y_grid(L_w(1,i),i),'k*')
        plot(x_grid(L_e(1,i),i),y_grid(L_e(1,i),i),'k*')
    end
    
    hold off

    % Have to ignore nan-values in mean (don`t mean over z-values under the ground)
    [m,n] = size(y_grid);
    T_grid_NaN = T_grid;
    for j = 1:m
        for k = 1:n
            for i = 1:length(height_c)
                if -h_grid_nonNaN(j,k) > height_c(i)
                    T_grid_NaN(j,k,i) = NaN;
                end
            end    
        end
    end

    T_sum2 = zeros(lat_points, length(height_c));
    depthcontour = zeros(1, lat_points);

    for iisum = 1:lat_points 
        T_sum = nanmean(T_grid_NaN(L_w(1,iisum):L_e(1,iisum),iisum,:));
        T_sum2(iisum,:) = squeeze(T_sum(1,1,:));

        % To make the plot nicer so white (NaN-)boxes are not seen 
        z_nan = find(isnan(T_sum2(iisum, :)),1);
        if isempty(z_nan) == 0 && z_nan ~= 1
            T_sum2(iisum, z_nan:end) = T_sum2(iisum, z_nan-1);
        end
        % Find the deepest point at every latitude
    
        depthcontour(1,iisum) = min(-h_grid_nonNaN(L_w(1,iisum):L_e(1,iisum),iisum));
    end

    [Y,Z] = meshgrid(y_grid(1,:),height_c(1,1,:));

    figure(51);
    contourf(Y,Z, T_sum2',25);
    
    xlabel('\bf Latitude')
    ylabel('\bf Depth (m)')
    if basin == 1
        title('\bf Global: Zonally averaged temperature')
    elseif basin == 2
        title('\bf Atlantic Ocean: Zonally averaged temperature')
    elseif basin == 3
        title('\bf Pacific Ocean: Zonally averaged temperature')
    end
    colorbar
    caxis([0 24])
    hold on

    % Plot depth

    h_max = height_f(1,1,end);
    x = y_grid(1,:);                               
    y1 = depthcontour(1,:);                                 
    y2 = h_max*ones(1,length(y_grid(1,:)));   
    X=[x,fliplr(x)];                                
    Y=[y1,fliplr(y2)];                               
    fill(X,Y,'k')   
    hold off 
end

%%\ Crossections along a latitude-line

% Must change boundaries if looking at the Atlantic Ocean
if basin == 2
    x_min = 259;
    x_max = 355;
    y_min = 25;
    y_max = 71;
   
    x_index1 = find(lon_c(:,1)==x_min);
    x_index2 = find(lon_c(:,1)==x_max);
    y_index1 = find(lat_c(1,:)==y_min);
    y_index2 = find(lat_c(1,:)==y_max);
end

latitude_line = latitude*ones(size(lon_c(x_index1+x_lat:x_index2-x_lat2,1)));

[XX, zz2] = meshgrid(lon_c(x_index1+x_lat:x_index2-x_lat2,1),height_c(1,1,:));

lat_index = find(lat_c(1,:)==latitude);

%-- Temperature

T_ave2 = squeeze(T_ave(x_index1+x_lat:x_index2-x_lat2,lat_index,:));

V2 = [0 0];     

fig1=figure(1);

contourf(XX,zz2,T_ave2',25)
colormap('Jet')
colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = height_f(1,1,end);
x2 = lon_c(x_index1+x_lat:x_index2-x_lat2,1);                                %#initialize x array
y1_2 = -h(x_index1+x_lat:x_index2-x_lat2,lat_index);                         %#create first curve
y2_2 = h_max*ones(1,length(lon_c(x_index1+x_lat:x_index2-x_lat2,1)));        %#create second curve
X2=[x2',fliplr(x2')];                                           %#create continuous x value array for plotting
Y2=[y1_2',fliplr(y2_2)];                                        %#create y values for out and then back
fill(X2,Y2,'k')                                                 %#plot filled area
ylim([height_c(1,end) 0])
xlabel('\bf Longitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Temperature at latitude ' num2str(latitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Temperature at latitude ' num2str(latitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Temperature at latitude ' num2str(latitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Temperature at latitude ' num2str(latitude)])
elseif basin == 5
    title(['\bf Drake Passage: Temperature at latitude ' num2str(latitude)])
end

hold off 

fig2=figure(2);

contourf(lon_c,lat_c,-h,V2)
xlim([x_min x_max]);
ylim([y_min y_max]);
colormap([0.7 0.7 0.7])
freezeColors

hold on

plot(lon_c(x_index1+x_lat:x_index2-x_lat2,1),latitude_line,'k--','LineWidth',2)
set(gca,'XTickLabel',[])
set(gca,'YTickLabel',[])
hold off

[h_m h_i]=inset(c,fig2, 0.35,2);
close(figure(1))
close(figure(2))

%-- Zonal velocity

u_ave1 = squeeze(u_c(x_index1+x_lat:x_index2-x_lat2,lat_index,:));

V2 = [0 0];     

fig1=figure(1);

contourf(XX,zz2,u_ave1',15)
colormap('Jet')
colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = height_f(1,1,end);
x2 = lon_c(x_index1+x_lat:x_index2-x_lat2,1);                                %#initialize x array
y1_2 = -h(x_index1+x_lat:x_index2-x_lat2,lat_index);                         %#create first curve
y2_2 = h_max*ones(1,length(lon_c(x_index1+x_lat:x_index2-x_lat2,1)));        %#create second curve
X2=[x2',fliplr(x2')];                                           %#create continuous x value array for plotting
Y2=[y1_2',fliplr(y2_2)];                                        %#create y values for out and then back
fill(X2,Y2,'k')                                                 %#plot filled area
ylim([height_c(1,end) 0])
xlabel('\bf Longitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Zonal velocity at latitude ' num2str(latitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Zonal velocity at latitude ' num2str(latitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Zonal velocity at latitude ' num2str(latitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Zonal velocity at latitude ' num2str(latitude)])
elseif basin == 5
    title(['\bf Drake Passage: Zonal velocity at latitude ' num2str(latitude)])
end

hold off 

fig2=figure(2);

contourf(lon_c,lat_c,-h,V2)
xlim([x_min x_max]);
ylim([y_min y_max]);
colormap([0.7 0.7 0.7])
freezeColors

hold on

plot(lon_c(x_index1+x_lat:x_index2-x_lat2,1),latitude_line,'k--','LineWidth',2)
set(gca,'XTickLabel',[])
set(gca,'YTickLabel',[])
hold off

[h_m h_i]=inset(c,fig2, 0.35,4);
close(figure(1))
close(figure(2))

%-- Meridional velocity

v_ave1 = squeeze(v_c(x_index1+x_lat:x_index2-x_lat2,lat_index,:));

V2 = [0 0];     

fig1=figure(1);

contourf(XX,zz2,v_ave1',15)
colormap('Jet')
colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = height_f(1,1,end);
x2 = lon_c(x_index1+x_lat:x_index2-x_lat2,1);                                %#initialize x array
y1_2 = -h(x_index1+x_lat:x_index2-x_lat2,lat_index);                         %#create first curve
y2_2 = h_max*ones(1,length(lon_c(x_index1+x_lat:x_index2-x_lat2,1)));        %#create second curve
X2=[x2',fliplr(x2')];                                           %#create continuous x value array for plotting
Y2=[y1_2',fliplr(y2_2)];                                        %#create y values for out and then back
fill(X2,Y2,'k')                                                 %#plot filled area
ylim([height_c(1,end) 0])
xlabel('\bf Longitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Meridional velocity at latitude ' num2str(latitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Meridional velocity at latitude ' num2str(latitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Meridional velocity at latitude ' num2str(latitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Meridional velocity at latitude ' num2str(latitude)])
elseif basin == 5
    title(['\bf Drake Passage: Meridional velocity at latitude ' num2str(latitude)])
end


hold off 

fig2=figure(2);

contourf(lon_c,lat_c,-h,V2)
xlim([x_min x_max]);
ylim([y_min y_max]);
colormap([0.7 0.7 0.7])
freezeColors

hold on

plot(lon_c(x_index1+x_lat:x_index2-x_lat2,1),latitude_line,'k--','LineWidth',2)
set(gca,'XTickLabel',[])
set(gca,'YTickLabel',[])
hold off

[h_m h_i]=inset(c,fig2, 0.35,3);
close(figure(1))
close(figure(2))

%%\ Crossections along a longitude-line

[xx, zz] = meshgrid(lat_c(1,y_index1:y_index2),height_c(1,1,:));
lon_index = find(lon_c(:,1)==longitude);
longitude_line = longitude*ones(size(lat_c(1,y_index1:y_index2)));

%-- Temperature

T_ave1 = squeeze(T_ave(lon_index,y_index1:y_index2,:));

fig1 = figure(1);

contourf(xx,zz,T_ave1',25)
colormap('Jet')
colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = height_f(1,1,end);
x = lat_c(1,y_index1:y_index2);                                %#initialize x array
y1 = -h(lon_index,y_index1:y_index2);                          %#create first curve
y2 = h_max*ones(1,length(lat_c(1,y_index1:y_index2)));         %#create second curve
X=[x,fliplr(x)];                               %#create continuous x value array for plotting
Y=[y1,fliplr(y2)];                             %#create y values for out and then back
fill(X,Y,'k')                                  %#plot filled area
ylim([height_c(1,end) 0])
xlabel('\bf Latitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Temperature at longitude ' num2str(longitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Temperature at longitude ' num2str(longitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Temperature at longitude ' num2str(longitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Temperature at longitude ' num2str(longitude)])
elseif basin == 5
    title(['\bf Drake Passage: Temperature at longitude ' num2str(longitude)])
end

hold off

fig2=figure(2);
contourf(lon_c,lat_c, -h,V2) %'Color', 'w','linewidth',1)
xlim([x_min x_max]);
ylim([y_min y_max]);
colormap([0.7 0.7 0.7])
freezeColors

hold on
plot(longitude_line,lat_c(1,y_index1:y_index2),'k--','LineWidth',2)
set(gca,'YTickLabel',[])
hold off
[h_m h_i]=inset(c,fig2,0.35,2);

close(figure(1))
close(figure(2))

%-- Zonal velocity

u_ave1 = squeeze(u_c(lon_index,y_index1:y_index2,:));

fig1 = figure(1);

contourf(xx,zz,u_ave1',15)

colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = min(-h(lon_index,y_index1:y_index2))-300;
x = lat_c(1,y_index1:y_index2);                                %#initialize x array
y1 = -h(lon_index,y_index1:y_index2);                          %#create first curve
y2 = h_max*ones(1,length(lat_c(1,y_index1:y_index2)));         %#create second curve
X=[x,fliplr(x)];                               %#create continuous x value array for plotting
Y=[y1,fliplr(y2)];                             %#create y values for out and then back
fill(X,Y,'k')                                  %#plot filled area
ylim([h_max 0])
xlabel('\bf Latitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Zonal velocity at longitude ' num2str(longitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Zonal velocity at longitude ' num2str(longitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Zonal velocity at longitude ' num2str(longitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Zonal velocity at longitude ' num2str(longitude)])
elseif basin == 5
    title(['\bf Drake Passage: Zonal velocity at longitude ' num2str(longitude)])
end

fig2 = figure(2);

contourf(lon_c,lat_c,-h,[0 0],'Color', 'k', 'linewidth',1)
colormap([0.7 0.7 0.7])
xlim([x_min x_max]);
ylim([y_min y_max]);
freezeColors
hold on

% Plot line
plot(longitude_line,lat_c(1,y_index1:y_index2),'k--','LineWidth',2)
set(gca,'YTickLabel',[])
hold off
[h_m h_i]=inset(c,fig2,0.35,4);
hold off
close(figure(1))
close(figure(2))

%-- Meridional velocity 

v_ave1 = squeeze(v_c(lon_index,y_index1:y_index2,:));

fig1 = figure(1);

contourf(xx,zz,v_ave1',15)

colorbar
c = get(fig1, 'children');
hold on

% Plot depth
    
h_max = min(-h(lon_index,y_index1:y_index2))-300;
x = lat_c(1,y_index1:y_index2);                                %#initialize x array
y1 = -h(lon_index,y_index1:y_index2);                          %#create first curve
y2 = h_max*ones(1,length(lat_c(1,y_index1:y_index2)));         %#create second curve
X=[x,fliplr(x)];                               %#create continuous x value array for plotting
Y=[y1,fliplr(y2)];                             %#create y values for out and then back
fill(X,Y,'k')                                  %#plot filled area
ylim([h_max 0])
xlabel('\bf Latitude')
ylabel('\bf Depth (m)')
if basin == 1
    title(['\bf Global: Meridional velocity at longitude ' num2str(longitude)])
elseif basin == 2
    title(['\bf Atlantic Ocean: Meridional velocity at longitude ' num2str(longitude)])
elseif basin == 3
    title(['\bf Pacific Ocean: Meridional velocity at longitude ' num2str(longitude)])
elseif basin == 4
    title(['\bf Indian Ocean: Meridional velocity at longitude ' num2str(longitude)])
elseif basin == 5
    title(['\bf Drake Passage: Meridional velocity at longitude ' num2str(longitude)])
end

fig2 = figure(2);

contourf(lon_c,lat_c,-h,[0 0],'Color', 'k', 'linewidth',1)
colormap([0.7 0.7 0.7])
xlim([x_min x_max]);
ylim([y_min y_max]);
freezeColors
hold on

% Plot line

plot(longitude_line,lat_c(1,y_index1:y_index2),'k--','LineWidth',2)
set(gca,'YTickLabel',[])
hold off
[h_m h_i]=inset(c,fig2,0.35,3);
hold off
close(figure(1))
close(figure(2))

%%\ Temperature along eastern and western boundary in Atlantic Ocean

if basin == 2
    T_westcoast = zeros(lat_points, length(height_c));
    T_eastcoast = zeros(lat_points, length(height_c));
    depth_west = zeros(1,lat_points);
    depth_east = zeros(1,lat_points);
    for ic = 1:lat_points
        T_westcoast(ic,:) = squeeze(T_grid(L_w(1,ic)+3, ic,:));
        depth_west(1,ic) = h_grid_nonNaN(L_w(1,ic)+3, ic);
        T_eastcoast(ic,:) = squeeze(T_grid(L_e(1,ic)-3, ic,:));
        depth_east(1,ic) = h_grid_nonNaN(L_e(1,ic)-3, ic);
    end
 
    [xx,zz] = meshgrid(y_grid(1,:), height_c(1,1,:));

    fig1=figure(1);
    contourf(xx,zz,T_westcoast',25)
    colorbar
    c = get(fig1, 'children');
    
    % Plot depth

    hold on 
    h_max = height_c(1,1,end);
    x2 = y_grid(1,:);                                
    y1_2 = -depth_west;                        
    y2_2 = h_max*ones(1,lat_points);        
    X2=[x2,fliplr(x2)];                                          
    Y2=[y1_2,fliplr(y2_2)];                                        
    fill(X2,Y2,'k')                                                 
    ylim([height_c(1,end) 0])
    xlabel('\bf Latitude')
    ylabel('\bf Depth (m)')
    hold off
    title('\bf North Atlantic: Temperature along western boundary')

    fig2=figure(2);
    contourf(x_grid,y_grid,-h_grid_nonNaN, [0 0])
    colormap([0.7 0.7 0.7])
    freezeColors

    hold on
    plot(x_grid(L_w+2,1),y_grid,'k--','LineWidth',2)
    set(gca,'XTickLabel',[])
    set(gca,'YTickLabel',[])
    hold off

    [h_m h_i]=inset(c,fig2, 0.35,2);
    close(figure(1))
    close(figure(2))

    fig1=figure(1);
    contourf(xx,zz,T_eastcoast',25)
    colorbar
    c = get(fig1, 'children');

    hold on 
    h_max = height_c(1,1,end);
    x2 = y_grid(1,:);                                
    y1_2 = -depth_east;                        
    y2_2 = h_max*ones(1,lat_points);        
    X2=[x2,fliplr(x2)];                                          
    Y2=[y1_2,fliplr(y2_2)];                                        
    fill(X2,Y2,'k')                                                 
    ylim([height_c(1,end) 0])
    xlabel('\bf Latitude')
    ylabel('\bf Depth (m)')
    title('\bf North Atlantic: Temperature along eastern boundary')
    hold off
    
    fig2=figure(2);
    contourf(x_grid,y_grid,-h_grid_nonNaN, [0 0])
    colormap([0.7 0.7 0.7])
    freezeColors

    hold on
    plot(x_grid(L_e-2,1),y_grid,'k--','LineWidth',2)
    set(gca,'XTickLabel',[])
    set(gca,'YTickLabel',[])
    hold off
    [h_m h_i]=inset(c,fig2, 0.35,2);
    close(figure(1))
    close(figure(2))
end

%% Temperaturedistribution in one point
close all

basin = 1;
% North Atlantic

if basin == 1                      % North Atlantic
    latitudes = 41;
    longitudes = 343; 
    H = 1050;
elseif basin == 2
    latitudes = -61;
    longitudes = 287;
     H = 1050;
elseif basin == 3                  % Nordic Seas
    latitudes = 71;
    longitudes = 347; 
    H = 200;
elseif basin == 4                  % South Pacific
    latitudes = -31;         
    longitudes = 221;
    H = 1250;
elseif basin == 5                  % South Atlantic
    latitudes = -31;
    longitudes = 331;
    H = 950;
end


lat_index = zeros(1,length(latitudes));
for j = 1:length(latitudes)
    lat_index(j) = find(lat_c(1,:) == latitudes(j));
end

lon_index = zeros(1,length(longitudes));
for k = 1:length(longitudes)
    lon_index(k) = find(lon_c(:,1) == longitudes(k));
end

colours = {'r.', 'b.', 'g.', 'c.'};
colours_line = {'r--o', 'b--v', 'g', 'c'};
colours_exp = {'--r', '--b', '--g', '--c'};
fig1 = figure(1);

for d = 1:length(longitudes)
    t_point = squeeze(T_ave(lon_index(d),lat_index,:));
    
    % Make values under ground NaN, such that this is not shown in plot.
    for i = 1:length(height_c)
        if -h(lon_index(d),lat_index)>height_c(i)
            t_point(i) = NaN;
        end
    end
    plot(t_point, height_c(:), colours_line{d})
    hold on

    level = 1;
    T_t = t_point(level);
    
    % 
    if isnan(t_point(end)) == 1
        t_nan = find(isnan(t_point), 1);
        T_b = t_point(t_nan-1);
    else
        T_b = t_point(end);
    end
    
    if isnan(t_point(end)) == 1
        e = exp((height_c(level:t_nan-1)-height_c(level))/H);
        T = (T_t-T_b)*e + T_b;
        Z = squeeze(height_c(1,1, level:t_nan-1));
        xlim([min(t_point)-2 max(t_point)+2]);
        ylim([height_c(t_nan-1) 0]);
    else
        e = exp((height_c(level:end)-height_c(level))/H);
        T = (T_t-T_b)*e + T_b;
        Z = squeeze(height_c(1,1, level:end));
        xlim([min(t_point)-2 max(t_point)+2]);
        ylim([height_c(end) 0]);
    end

    T = squeeze(T(1,1,:));

    plot(T, Z', colours_exp{d});
    
    dTdz = zeros(1, length(t_point)-1);
    for is = 1 : length(t_point)-1
    if height_c(is+1) < -h(lon_index,lat_index)
        height_ett = -h(lon_index,lat_index);
    else height_ett = height_c(is+1);
    end
    dTdz(is) = (t_point(is+1)-t_point(is))/(height_ett-height_c(is));   
    end
    
    xlabel('\bf Temperature ({\circ}C)')
    ylabel('\bf Depth (m)')
    hold off
    
end


fig2 = figure(2);
contourf(lon_c,lat_c,-h,[0 0])
%xlim([x_min x_max]);
%ylim([y_min y_max]);
colormap([0.7 0.7 0.7])
set(gca,'XTickLabel',[])
set(gca,'YTickLabel',[])
freezeColors
hold on 
for ii = 1:length(longitudes)
    plot(longitudes(ii),latitudes, colours{ii})
end

[h_m h_i]=inset_less_low(fig1,fig2,0.45);
legend(h_m, ['lon: ' num2str(longitudes) ' ; lat: = ' num2str(latitudes)], ...
    ['Te^{z/H} where H =' num2str(H)]);
close(figure(1))
close(figure(2))
%legend(legendInfo,'interpreter','latex')

figure;

plot(dTdz,squeeze(height_f(1,1,2:end-1)),'k')
xlabel('\bf dT/dz')
ylabel('\bf Depth (m)')
legend(['lon: ' num2str(longitudes) ' and lat: = ' num2str(latitudes)]);
ylim([height_f(end-3) 0]);


