
function [psi, depthcontour] = stromfunk(h, v, west_point, east_point,lat)

% Import needed information
lon_c = rdmds('../Grid/XC');
height_c = rdmds('../Grid/RC');
height_f = rdmds('../Grid/RF');

% Calculate V (and remember dx varies with latitude)

nz = length(height_c);

R = 6371000;                                % Radius of Earth in m
theta = lat(1,:);                           % Angle
r = R*cosd(theta);                          % Local radius
dx = (2*pi*r)/length(lon_c(:,1));           % distance between points at latitude theta

[lon_points,lat_points] = size(lat);

v_sum2 = zeros(lat_points, nz);
depthcontour = zeros(1, lat_points);

for iisum = 1:lat_points 
    v_sum = nansum(v(west_point(1,iisum):east_point(1,iisum),iisum,:))*dx(iisum);
    v_sum2(iisum,:) = squeeze(v_sum(1,1,:));
    
    % Find the deepest point at every latitude
    
    depthcontour(1,iisum) = min(-h(west_point(1,iisum):east_point(1,iisum),iisum));
end


% Calculate psi (and remember dz varies with height)

psi = zeros(lat_points,nz+1);

for j = 1:lat_points
    psi(j,1) = 0;
    for k = 2:nz+1
        psi(j,k) = psi(j,k-1) + v_sum2(j,k-1)*abs((height_f(k)-height_f(k-1)));
    end
end

psi = 10^(-6).*psi;
end


