function [H,x,y]=extract_etopo1(lon_lo,lon_hi,lat_lo,lat_hi)
%
% Extract ETOPO1 data from archive file /mn/vann/metos-d5/adagj/MITgcm_stuff/topography/ETOPO/etopo1_ice_g_f4.flt'
%
% e.g.
%   [H,x,y]=extract_etopo5(-180,180,-90,90);
%   [H,x,y]=extract_etopo5(0,360,-90,90);
%   [H,xe,ye]=extract_etopo5(-97.5,12.5,-15,70-1/12);

% HEADER for '/mn/vann/metos-d5/adagj/MITgcm_stuff/topography/ETOPO/etopo1_ice_g_f4.flt'
% ncols         21601
% nrows         10801
% xllcenter     -180.00
% yllcenter     -90.00
% cellsize      0.01666666667
% NODATA_value  -99999
% byteorder     LSBFIRST
% NUMBERTYPE    4_BYTE_FLOAT
% MIN_VALUE     -10898.0
% MAX_VALUE     8271.0

% byteorder     LSBFIRST  means Little-endian ordering which has the value
% 'l' in matlab

fid=fopen('/mn/vann/metos-d5/adagj/MITgcm_stuff/topography/ETOPO/etopo1_ice_g_f4.flt','r','l');
if fid <0 
 sprintf('I failed to open the file')
 return
end

% ETOPO1 has a 1 arc-minute resolution
dt=60;

% define index vectors to get the ETOPO1 data in accordance with the MITgcm
% grid
i0=round(lon_lo*dt)+1;
i1=round(lon_hi*dt)+1;
j0=round((lat_lo+90)*dt )+1;
j1=round((lat_hi+90)*dt )+1;
if i1>i0
ii=i0:i1;
else
 ii=[i0:360*dt 1:i1];
end
% the index vector ii = [nrows/2:end+1, 1:nrows/2] reshape the etopo1
% matrix to get 0 degrees lon at the correct location (in accordance with MITgcm)
ii=mod(ii+180*dt-1,360*dt+1)+1;
%ii=mod(ii+180*dt,360*dt+1)+1;
jj=j0:j1;

nx=numel(ii);
ny=numel(jj);

H5=reshape( fread(fid,(360*dt+1)*(180*dt+1),'real*4'), [360*dt+1 180*dt+1]);
%H5=reshape( fread(fid,(360*dt+1)*(180*dt+1),'real*4'), [180*dt+1 360*dt+1]);
fclose(fid);

% Reshape H5 using the index vectors (to get the pacific in the middle)
H=H5(ii,jj);
H=fliplr(H)';
% define longitude (x) and latitude (y) vectors in accordance with the H
% matrix
xe=(0:(360)*dt)/dt;
% if lon_lo<0 || lon_hi<0
%  xe=mod(xe+180,360)-180;
%  x=xe(ii);
% else
ii2=i0:i1;
x=xe(ii2);
%end
ye=(0:180*dt)/dt-90;
y=ye(jj);
end